@@ -41,6 +41,7 @@ try:
         ComponentType,
     )
     from azure.ml.component.pipeline import PipelineParameter
+    from azureml.exceptions._azureml_exception import UserErrorException
 except ImportError as error:
     raise ImportError(
         f"{error.msg}. Please install using `pip install shrike[pipeline]`."
@@ -177,7 +178,42 @@ class AMLPipelineHelper:
         # subgraph_instance.setup(self.pipeline_config)
         return subgraph_instance.build(subgraph_config)
 
-    def dataset_load(self, name, version="latest"):
+    def dataset_load(
+        self,
+        name,
+        version="latest",
+        datastore=None,
+        path_on_datastore=None,
+        description=None,
+    ):
+        """Loads a dataset by either id or name. If the workspace does not contain this dataset and path is given, create the dataset.
+
+        Args:
+            name (str): name or uuid of dataset to load
+            version (str): if loading by name, used to specify version (default "latest")
+            datastore (str): datastore for registering the dataset as <name>
+            path_on_datastore (str): path for registering the dataset as <name>
+            description (str): description of dataset to register
+        """
+        try:
+            return self._dataset_load_by_name_or_id(name, version)
+        except UserErrorException:
+            log.info(
+                f"Dataset {name} not found. Try registering from {path_on_datastore} on {datastore}..."
+            )
+            dataset = Dataset.File.from_files(
+                path=[(Datastore(self.workspace(), datastore), path_on_datastore)],
+                validate=False,
+            )
+            dataset = dataset.register(
+                workspace=self.workspace(),
+                name=name,
+                description=description,
+                create_new_version=True,
+            )
+            return dataset
+
+    def _dataset_load_by_name_or_id(self, name, version):
         """Loads a dataset by either id or name.
 
         Args:
